==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/history/translations/history_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historial de conversaciones</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Guardar mensajes en el historial</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Guardar conversaciones de usuarios anónimos</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Cambios de Estado</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Guardar cambios de estado</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Guardar cambios de estado en el historial</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Guardar estado sólo con la descripción</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Ver historial</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation>Guardar conversaciones en el historial</translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation>Historial en ventana de conversación</translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation>Mostrar mensajes del historial desde</translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation>Seleccionar el período de tiempo en el que los mensajes pueden ser citados en la ventana de conversación</translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation>ayer</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>semana pasada</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>último mes</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation>Limitar el número de mensajes del historial</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Ventana de conversación</translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Historial de conversación</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Limpiar Historial de Conversación</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Limpiar Historial</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Conservar historial</translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Conservar historial</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Eliminar entradas</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>¿De verdad quieres eliminar el historial?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation>Eliminar historial</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Limpiar Estado del Historial</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Limpiar el Historial SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversaciones</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Estados</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversaciones</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation>- Todas las conversaciones -</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Estados</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation>- Todos los amigos -</translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>Smses</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation>- Todos los destinatarios -</translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Por fecha</translation>
    </message>
    <message>
        <source>to</source>
        <translation>para</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Amigo</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinatario</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Ver Historial de Conversación</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Mostrar los últimos %1 de mensajes</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Mostrar mensajes desde ayer</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Mostrar mensajes de los últimos 7 días</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Mostrar mensajes de los últimos 30 días</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Mostrar el historial completo</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/history/translations/history_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historial de conversaciones</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Guardar mensajes en el historial</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Guardar conversaciones de usuarios anónimos</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Cambios de Estado</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Guardar cambios de estado</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Guardar cambios de estado en el historial</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Guardar estado sólo con la descripción</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Ver historial</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation>Guardar conversaciones en el historial</translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation>Historial en ventana de conversación</translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation>Mostrar mensajes del historial desde</translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation>Seleccionar el período de tiempo en el que los mensajes pueden ser citados en la ventana de conversación</translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation>ayer</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>semana pasada</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>último mes</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation>Limitar el número de mensajes del historial</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Ventana de conversación</translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Historial de conversación</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Limpiar Historial de Conversación</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Limpiar Historial</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Conservar historial</translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Conservar historial</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Eliminar entradas</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>¿De verdad quieres eliminar el historial?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation>Eliminar historial</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Limpiar Estado del Historial</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Limpiar el Historial SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversaciones</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Estados</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversaciones</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation>- Todas las conversaciones -</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Estados</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation>- Todos los amigos -</translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>Smses</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation>- Todos los destinatarios -</translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Por fecha</translation>
    </message>
    <message>
        <source>to</source>
        <translation>para</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversar</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Amigo</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinatario</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Ver Historial de Conversación</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Mostrar los últimos %1 de mensajes</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Mostrar mensajes desde ayer</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Mostrar mensajes de los últimos 7 días</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Mostrar mensajes de los últimos 30 días</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Mostrar el historial completo</translation>
    </message>
</context>
</TS>
